import AdminUserModel from '../../../common/data/model/adminUserModel';
import IOtpAuthRepo from '../data/repository/IOtpAuthRepo';
import OtpAuthUsecaseException from './otpException';

export type AdminOtpData = {
  otp: string;
  phonenumber: string;
};

export interface IOtpAuthUsecase {
  execute(data: AdminOtpData): Promise<AdminUserModel>;
}

export default class OtpAuthUsecase implements IOtpAuthUsecase {
  private repository: IOtpAuthRepo;

  private validLenghtOfOtp = 6;

  constructor(repository: IOtpAuthRepo) {
    this.repository = repository;
  }

  async execute(data: AdminOtpData): Promise<AdminUserModel> {
    // check length of otp
    const isOtpValid = this.isOtpValid(data.otp);
    if (!isOtpValid) throw new OtpAuthUsecaseException();
    // call the repo
    const updatedAdminModal = await this.repository.execute(data);
    return updatedAdminModal;
  }

  private isOtpValid(otp: string) {
    return !!(otp.length >= this.validLenghtOfOtp);
  }
}
