import IPhoneNumberAuthRepo from '../data/repository/IPhoneNumberAuthRepo';
import PhonenumberException from './exception';

export type AdminData = {
  phonenumber: string;
};

interface IPhoneNumberAuthUsecase {
  execute(adminData: AdminData): Promise<string>;
}

export default class PhonenumberAuthUsecase implements IPhoneNumberAuthUsecase {
  private repository: IPhoneNumberAuthRepo;

  private wrongPhoneNumberMessage: string;

  constructor(repository: IPhoneNumberAuthRepo, wrongPhoneNumberMessage: string) {
    this.repository = repository;
    this.wrongPhoneNumberMessage = wrongPhoneNumberMessage;
  }

  async execute(adminData: AdminData): Promise<string> {
    // check phone number regex
    const isPhoenumberValid = this.isPhoneNumberValid(adminData.phonenumber);
    if (!isPhoenumberValid) throw new PhonenumberException(this.wrongPhoneNumberMessage);

    const response = await this.repository.execute(adminData);

    return response;
  }

  private isPhoneNumberValid(phonenumber: string) {
    const regex = /\(?([0-9]{3})\)?([ .-]?)([0-9]{3})\2([0-9]{4})/;
    return regex.test(phonenumber);
  }
}
