/* eslint-disable consistent-return */
/* eslint-disable no-underscore-dangle */
import React from 'react';
import getPlaces from '~/business-logic/core/places/get-places';
import getPlacesAdapter from '~/driven/adapters/get-places-adapter/getPlacesAdapter';
import PlacesModel from '~/business-logic/core/places/common/model/placesModel';
import { prepareStateManagementForVM } from '~/driven/utils/helpers/globalHelpers';
import useGetNavigatorAndTokenUpdater from '~/driven/utils/helpers/hooks/getNavigatorAndAccessTokenUpdator';
import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';
import { apiUrls } from '~/driven/utils/configs/appConfig';
import { HttpOptionsType } from '~/driven/boundaries/http-boundary/protocols';
import { HTTPPovider } from '~/driven/boundaries/http-boundary/httpBoundary';
import { QrPlace } from '~/business-logic/core/places/common/entity/placeEntity';
import PlacesListView from '../view/PlacesListView';
import usePlacesListVM from '../viewmodel/placesListVM';
import placesListModel from '../model/placesListModel';

type QrCodeResponse = {
  one_time: false;
  place_id: string;
  user_id: string;
  _id: string;
}[];
const QrCodeRO = (response: QrCodeResponse): QrPlace[] => {
  return response.map((qrCode) => ({
    id: qrCode._id,
    oneTime: qrCode.one_time,
    placeId: qrCode.place_id,
    userId: qrCode.user_id,
  }));
};

const prepareTheLogicForModel = () => {
  const { accessTokenUpdateHandler, notLoginAuth, userData } = useGetNavigatorAndTokenUpdater();

  const { user } = userData;
  const gettingPlacesDrivenAdapter = getPlacesAdapter(user as AdminUserModel, accessTokenUpdateHandler, notLoginAuth);
  const { url } = gettingPlacesDrivenAdapter;
  const getingPlacesLogic = getPlaces(gettingPlacesDrivenAdapter);
  return { getingPlacesLogic, url };
};

export interface IPlacesListProps {
  selectedRowId: string;
  setSelectedRowId: React.Dispatch<React.SetStateAction<string>>;
}

export default function PlacessList(props: IPlacesListProps) {
  const { selectedRowId, setSelectedRowId } = props;
  const { accessTokenUpdateHandler, notLoginAuth, userData } = useGetNavigatorAndTokenUpdater();

  const getQrCodes = async () => {
    try {
      // url
      const apiUrl = apiUrls.core.getQrs;
      // options
      const apiOptions: HttpOptionsType = {
        url: apiUrl,
      };
      // request
      const userToken = {
        accessToken: userData.user?.adminUserData.accessToken || null,
        refreshToken: userData.user?.adminUserData.refreshToken || null,
      };
      const httpProvider = new HTTPPovider(userToken, accessTokenUpdateHandler, notLoginAuth);
      const response = await httpProvider.request<QrCodeResponse>(apiOptions);
      const qrCodeList = QrCodeRO(response);
      return qrCodeList;
      // update the query
    } catch (error) {
      console.log(error);
    }
  };

  const { getingPlacesLogic, url } = prepareTheLogicForModel();
  const getPlacesWithQrLogic = async () => {
    const placesList = await getingPlacesLogic();
    const qrCodesList = await getQrCodes();
    placesList.setQrFor(qrCodesList || []);
    return placesList;
  };
  const placesModel = async () => await placesListModel(getPlacesWithQrLogic);
  const useGetPlacesList = prepareStateManagementForVM<PlacesModel>(url, placesModel);
  const { placesData } = usePlacesListVM({
    useGetPlacesList,
  });

  return <PlacesListView placesList={placesData} selectedRowId={selectedRowId} setSelectedRowId={setSelectedRowId} />;
}
