import React from 'react';
import createAccountAdapter from '~/driven/adapters/create-account-adapter/createAccountAdapter';
import createProfileAdapter from '~/driven/adapters/create-profile-adapter/createProfileAdapter';
import CreateUserInfra from '~/business-logic/core/users/create-user';
import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';
import useGetNavigatorAndTokenUpdater from '~/driven/utils/helpers/hooks/getNavigatorAndAccessTokenUpdator';
import CreateUserView from '../view/CreateUserView';
import useCreateUserVM from '../viewmodel/CreateUserVM';
import createUserModel from '../model/createUserModel';

export default function CreateUser() {
  const { accessTokenUpdateHandler, notLoginAuth, userData } = useGetNavigatorAndTokenUpdater();

  const { user } = userData;
  // get adapters from driven layer
  const createAccountDrivenAdapter = createAccountAdapter(
    user as AdminUserModel,
    accessTokenUpdateHandler,
    notLoginAuth,
  );
  const createProfileDrivenAdapter = createProfileAdapter(
    user as AdminUserModel,
    accessTokenUpdateHandler,
    notLoginAuth,
  );
  // pass to the logic and get the usecase
  const createUserInfra = new CreateUserInfra(createAccountDrivenAdapter, createProfileDrivenAdapter);
  const createUserLogic = createUserInfra.execute();
  // pass the usecase to the model
  const { handleSubmitForm } = createUserModel({ createUserLogic });
  // pass the method to the viewmodel to call on submit
  const { stateHandler, onSubmit, inputNames, error, setError } = useCreateUserVM({ handleSubmitForm });
  // get all of the needed information to the user to show
  return (
    <CreateUserView
      error={error}
      setError={setError}
      stateHandler={stateHandler}
      inputNames={inputNames}
      onSubmit={onSubmit}
    />
  );
}
