import React from 'react';
import PrimaryButton from '~/driven/utils/components/buttons/primary-button/PrimaryButton';
import SimpleInput from '~/driven/utils/components/inputs/simple-input/SimpleInput';
import { staticMessages } from '~/driven/utils/constants/staticMessages';
import Notification from '~/driven/utils/components/Notification/Notification';
import ICreateUserViewProps from './protocols';

export default function CreateUserView(props: ICreateUserViewProps) {
  const { onSubmit, inputNames, stateHandler, error, setError } = props;
  const { inputStates, inputsSetStates } = stateHandler;

  const inputs = inputNames.map((inputName) => {
    const title = staticMessages.global[inputName] as string;
    return (
      <SimpleInput
        inputData={{
          title,
          name: inputName,
        }}
        stateHanlder={{
          setState: inputsSetStates,
          state: inputStates[inputName],
        }}
        key={inputName}
        className='mb-4 w-[48%] px-2'
      />
    );
  });
  return (
    <form onSubmit={onSubmit} className='px-4 my-8'>
      {Boolean(error.message) && (
        <Notification
          message={error.message}
          type={error.type}
          onCloseCallback={() => setError({ message: '', type: 'error' })}
        />
      )}
      <div className='flex flex-wrap w-full gap-4'>{inputs}</div>
      <div className='flex'>
        <PrimaryButton onClick={() => null} title={staticMessages.global.submit} />
      </div>
    </form>
  );
}
