import React from 'react';
import getUsersAdapter from '~/driven/adapters/get-users-adapter/getUsersAdapter';
import getUsers from '~/business-logic/core/users/get-users';
import UsersModel from '~/business-logic/core/users/common/data/model/usersModel';
import { prepareStateManagementForVM } from '~/driven/utils/helpers/globalHelpers';
import useGetNavigatorAndTokenUpdater from '~/driven/utils/helpers/hooks/getNavigatorAndAccessTokenUpdator';
import AdminUserModel from '~/business-logic/generic/admin-user/common/data/model/adminUserModel';
import useUsersListVM from '../viewmodel/usersListVM';
import UsersListView from '../view/UsersListView';
import usersListModel from '../model/usersListModel';

const usePrepareTheLogicForModel = () => {
  const { accessTokenUpdateHandler, notLoginAuth, userData } = useGetNavigatorAndTokenUpdater();

  const { user } = userData;
  const gettingUsersDrivenAdapter = getUsersAdapter(user as AdminUserModel, accessTokenUpdateHandler, notLoginAuth);
  const { url } = gettingUsersDrivenAdapter;
  const getingusersLogic = getUsers(gettingUsersDrivenAdapter);
  return { getingusersLogic, url };
};

export interface IUsersListProps {
  selectedRowId: string;
  setSelectedRowId: React.Dispatch<React.SetStateAction<string>>;
}
export default function UsersList(props: IUsersListProps) {
  const { selectedRowId, setSelectedRowId } = props;
  const { getingusersLogic, url } = usePrepareTheLogicForModel();
  const usersModel = async () => await usersListModel(getingusersLogic);
  const useGetusersList = prepareStateManagementForVM<UsersModel>(url, usersModel);
  const { usersData } = useUsersListVM({
    useGetusersList,
  });
  return <UsersListView usersList={usersData} selectedRowId={selectedRowId} setSelectedRowId={setSelectedRowId} />;
}
